@@ -1,6 +1,6 @@
 //
 // WORefMenu.hh for pekwm
-// Copyright © 2004-2009 Claes Nästen <me{@}pekdon{.}net>
+// Copyright (C) 2004-2020 Claes Nästen <pekdon@gmail.com>
 //
 // This program is licensed under the GNU GPL.
 // See the LICENSE file for more information.
@@ -15,19 +15,17 @@
 
 #include "Client.hh"
 
-using std::string;
-using std::wstring;
-
 //! @brief WORefMenu constructor
 //! @param theme Pointer to Theme
 //! @param title Title of menu
 //! @param name Name of menu
 //! @param decor_name Name of decor, defaults to MENU
-WORefMenu::WORefMenu(Theme *theme, const std::wstring &title,
-                     const std::string &name, const std::string &decor_name)
-    : PMenu(theme, title, name, decor_name), PWinObjReference(0),
-      _title_base(title),
-      _title_pre(L" ["), _title_post(L"]")
+WORefMenu::WORefMenu(const std::string &title,
+		     const std::string &name, const std::string &decor_name)
+	: PMenu(title, name, decor_name),
+	  PWinObjReference(nullptr),
+	  _title_base(title),
+	  _title_pre(" ["), _title_post("]")
 {
 }
 
@@ -43,23 +41,25 @@ WORefMenu::~WORefMenu(void)
 void
 WORefMenu::notify(Observable *observable, Observation *observation)
 {
-    PWinObjReference::notify(observable, observation);
-    unmapAll();
+	PWinObjReference::notify(observable, observation);
+	unmapAll();
 }
 
 //! @brief Sets the reference and updates the title
 void
 WORefMenu::setWORef(PWinObj *wo_ref)
 {
-    PWinObjReference::setWORef(wo_ref);
+	PWinObjReference::setWORef(wo_ref);
 
-    wstring title(_title_base);
+	std::string title(_title_base);
 
-    // if of client type, add the clients named to the title
-    if (wo_ref && (wo_ref->getType() == PWinObj::WO_CLIENT)) {
-        Client *client = static_cast<Client*>(wo_ref);
-        title += _title_pre + client->getTitle()->getVisible() + _title_post;
-    }
+	// if of client type, add the clients named to the title
+	if (wo_ref && (wo_ref->getType() == PWinObj::WO_CLIENT)) {
+		Client *client = static_cast<Client*>(wo_ref);
+		title += _title_pre
+			 + client->getTitle()->getVisible()
+			 + _title_post;
+	}
 
-    setTitle(title);
+	setTitle(title);
 }
